@@ -515,21 +515,20 @@ rmd_RCM_Hist_compare <- function() {
     "```\n",
     "",
     "```{r, fig.cap = \"Comparison of total removals between the OM and RCM.\"}",
+    "RCM_C <- sapply(x@Misc, function(xx) rowSums(xx$Cpred)) %>% t()",
     "matplot(Year, t(Hist_C), typ = \"o\", col = \"red\", pch = 16, xlab = \"Year\", ylab = \"Total removals\",",
-    "        ylim = c(0, 1.1 * max(c(Hist_C, RCMdata@Chist, na.rm = TRUE))))",
-    "lines(Year, rowSums(RCMdata@Chist, na.rm = TRUE), col = \"black\")",
+    "        ylim = c(0, 1.1 * max(Hist_C, RCMdata@Chist)))",
+    "matlines(Year, t(RCM_C[sims, , drop = FALSE]), col = \"black\")",
     "abline(h = 0, col = \"grey\")",
     "legend(\"topleft\", c(\"RCM\", \"OM\"), col = c(\"black\", \"red\"), pch = c(NA_integer_, 16), lwd = c(1, 1), bty = \"n\")",
     "```\n",
     "",
-    "```{r, fig.cap = \"Difference in annual catch (relative to observed), calculated as $C^{OM}_y/C^{obs}_y - 1$. Positive values indicate higher catch in the OM. Catch in the OM is the total removals (both landings and discards).\"}",
-    "if(any(RCMdata@Chist > 0, na.rm = TRUE)) {",
-    "Catch_difference <- t(Hist_C)/rowSums(RCMdata@Chist, na.rm = TRUE) - 1",
+    "```{r, fig.cap = \"Difference in removals (relative to RCM predicted), calculated as $C^{OM}_y/C^{RCM}_y - 1$. Positive values indicate higher removals in the OM.\"}",
+    "Catch_difference <- t(Hist_C/RCM_C[sims, , drop = FALSE]) - 1",
     "Catch_difference[is.infinite(Catch_difference)] <- 0",
-    "matplot(Year, Catch_difference, typ = \"n\", xlab = \"Year\", ylab = \"Difference in relative catch\")",
+    "matplot(Year, Catch_difference, typ = \"n\", xlab = \"Year\", ylab = \"Difference in relative removals\")",
     "abline(h = 0, col = \"grey\")",
     "matlines(Year, Catch_difference, col = \"black\")",
-    "}",
     "```\n")
 }
 
