@@ -47,12 +47,7 @@ rmd_summary <- function(modname) {
 
 
 ### Life history
-vector2char <- function(x) paste0("c(", paste0(x, collapse = ", "), ")")
-
 rmd_at_age <- function(age, y_var, fig.cap, label, header = NULL) {
-  age <- vector2char(age)
-  y_var <- vector2char(y_var)
-
   ans <- c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
            paste0("plot_generic_at_age(", age, ", ", y_var, ", label = \"", label, "\")"),
            " ```\n")
@@ -60,26 +55,42 @@ rmd_at_age <- function(age, y_var, fig.cap, label, header = NULL) {
   return(ans)
 }
 
-rmd_LAA <- function(age, LAA, header = NULL) {
-  rmd_at_age(age, LAA, fig.cap = "Mean length-at-age from Data object.", label = "Mean Length-at-age", header = header)
+rmd_LAA <- function(age = "1:info$data$n_age - 1", LAA = "info$LH$LAA", header = NULL, SD_LAA = "",
+                    fig.cap = "Mean length-at-age from Data object.") {
+  if(nchar(SD_LAA)) {
+    fig.cap <- paste(fig.cap, "Dotted lines indicate 95% intervals for variability in length-at-age.")
+    SD_LAA_calc <- c(paste("SD_low <-", LAA, "- 1.96 *", SD_LAA),
+                     paste("SD_high <- ", LAA, "+ 1.96 *", SD_LAA),
+                     "ymax <- 1.1 * max(SD_high)")
+    SD_LAA_plot <- paste0("lines(", age, ", SD_low, lty = 3); lines(", age, ", SD_high, lty = 3)")
+  } else {
+    SD_LAA_calc <- paste0("ymax <- 1.1 * max(", LAA, ")")
+    SD_LAA_plot <- ""
+  }
+  
+  ans <- c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
+           SD_LAA_calc,
+           paste0("plot_generic_at_age(", age, ", ", LAA, ", label = \"Length-at-age\", ymax = 1.1 * ymax)"),
+           SD_LAA_plot,
+           " ```\n")
+  if(!is.null(header)) ans <- c(header, ans)
+  return(ans)
 }
 
-rmd_WAA <- function(age, WAA, header = NULL) {
+rmd_WAA <- function(age = "1:info$data$n_age - 1", WAA = "info$LH$WAA", header = NULL) {
   rmd_at_age(age, WAA, fig.cap = "Mean weight-at-age from Data object.", label = "Mean Weight-at-age", header = header)
 }
 
-rmd_LW <- function(LAA, WAA) {
-  LAA_char <- paste0("c(", paste0(LAA, collapse = ", "), ")")
-  WAA_char <- paste0("c(", paste0(WAA, collapse = ", "), ")")
-
-  return(c("```{r, fig.cap=\"Length-weight relationship.\"}",
-           paste0("plot(", LAA_char, ", ", WAA_char, ", typ = \"o\", xlab = \"Length\", ylab = \"Weight\")"),
-           "abline(h = 0, col = \"grey\")",
-           "```\n"))
+rmd_LW <- function(LAA = "info$LH$LAA", WAA = "info$LH$WAA") {
+  c("```{r, fig.cap=\"Length-weight relationship.\"}",
+    paste0("plot(", LAA, ", ", WAA, ", typ = \"o\", xlab = \"Length\", ylab = \"Weight\")"),
+    "abline(h = 0, col = \"grey\")",
+    "```\n")
 }
 
-rmd_mat <- function(age, mat, fig.cap) rmd_at_age(age, mat, fig.cap, "Maturity")
-
+rmd_mat <- function(age = "1:info$data$n_age - 1", mat = "info$data$mat", fig.cap) {
+  rmd_at_age(age, mat, fig.cap, "Maturity")
+}
 
 
 
@@ -101,8 +112,15 @@ rmd_data_timeseries <- function(type, header = NULL, is_matrix = FALSE, nsets =
   return(ans)
 }
 
+rmd_data_MW <- function(header = NULL) {
+  ans <- c("```{r, fig.cap=\"Mean weight time series.\"}",
+           "plot_timeseries(info$Year, info$data$MW_hist, label = \"Mean weight\")",
+           "```\n")
+  if(!is.null(header)) ans <- c(header, ans)
+  return(ans)
+}
 
-rmd_data_age_comps <- function(type = c("bubble", "annual"), ages = "0:(info$data$n_age-1)", annual_yscale = "\"proportions\"",
+rmd_data_age_comps <- function(type = c("bubble", "annual"), ages = "1:info$data$n_age - 1", annual_yscale = "\"proportions\"",
                                annual_ylab = "\"Frequency\"")  {
   type <- match.arg(type)
   if(type == "bubble") {
@@ -119,6 +137,25 @@ rmd_data_age_comps <- function(type = c("bubble", "annual"), ages = "0:(info$dat
     "```\n")
 }
 
+rmd_data_length_comps <- function(type = c("bubble", "annual"), 
+                                  CAL_bins = "info$LH$CAL_mids", annual_yscale = "\"proportions\"",
+                                  annual_ylab = "\"Frequency\"")  {
+  type <- match.arg(type)
+  if(type == "bubble") {
+    arg <- "\"bubble_data\""
+    fig.cap = "Length composition bubble plot."
+  } else {
+    arg <- "\"annual\""
+    fig.cap <- "Annual length compositions."
+  }
+  c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
+    "ind_valid <- obj$env$data$CAL_n > 0",
+    "CALobs <- obj$env$data$CAL_hist * obj$env$data$CAL_n", 
+    paste0("plot_composition(info$Year[ind_valid], CALobs[ind_valid, ], N = obj$env$data$CAL_n, CAL_bins = ", CAL_bins, ", plot_type = ", arg, ","),
+    paste0("                 annual_yscale = ", annual_yscale, ", annual_ylab = ", annual_ylab, ")"),
+    "```\n")
+}
+
 #### Assessment parameters
 rmd_R0 <- function(header = NULL) {
   fig.cap <- "Estimate of R0, distribution based on normal approximation of estimated covariance matrix."
@@ -134,19 +171,6 @@ rmd_R0 <- function(header = NULL) {
   return(ans)
 }
 
-rmd_meanR <- function(header = NULL) {
-  fig.cap <- "Estimate of mean recruitment, distribution based on normal approximation of estimated covariance matrix."
-  ans <- c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
-           "if(conv) {",
-           "  ind <- names(SD$par.fixed) == \"meanRx\"",
-           "  mu <- SD$par.fixed[ind] - log(obj$env$data$rescale)",
-           "  sig <- sqrt(diag(SD$cov.fixed)[ind])",
-           "  plot_lognormalvar(mu, sig, label = \"Mean recruitment\", logtransform = TRUE)",
-           "}",
-           "```\n")
-  if(!is.null(header)) ans <- c(header, ans)
-  return(ans)
-}
 
 
 rmd_h <- function() {
@@ -159,6 +183,19 @@ rmd_h <- function() {
     "```\n")
 }
 
+rmd_M_prior <- function() {
+  fig.cap <- "Estimate of natural mortality, distribution based on normal approximation of posterior distribution."
+  ans <- c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
+           "if(any(grepl(\"log_M\", names(SD$par.fixed))) && conv) {",
+           "  ind <- grepl(\"log_M\", names(SD$par.fixed))",
+           "  mu <- SD$par.fixed[ind]",
+           "  sig <- sqrt(diag(SD$cov.fixed)[ind])",
+           "  plot_lognormalvar(mu, sig, label = \"Natural mortality\", logtransform = TRUE)",
+           "}",
+           "```\n")
+  return(ans)
+}
+
 rmd_FMSY <- function(header = NULL) {
   fig.cap <- "Estimate of FMSY, distribution based on normal approximation of estimated covariance matrix."
   ans <- c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
@@ -196,26 +233,46 @@ rmd_F_FMSY_terminal <- function() {
     "```\n")
 }
 
-rmd_M <- function() {
+rmd_M_rw <- function() {
   out <- c("```{r, fig.cap = \"Estimates of M with 95% confidence intervals. Dotted horizontal lines indicate bounds specified in model.\"}",
-           "logit_M <- SD$value[names(SD$value) == \"logit_M\"]",
-           "M_bounds <- obj$env$data$M_bounds",
-           "M <- ilogit2(logit_M, M_bounds[1], M_bounds[2], TMB_report$M[1])",
-           "if(conv) {",
-           "  logit_M_sd <- SD$sd[names(SD$value) == \"logit_M\"]",
-           "} else {",
-           "  logit_M_sd <- rep(0, length(M))",
+           "RWM <- info$data$tv_M == \"walk\"",
+           "if(RWM) {",
+           "  logit_M <- SD$value[grepl(\"logit_M\", names(SD$value))]",
+           "  M_bounds <- obj$env$data$M_bounds",
+           "  M0 <- TMB_report$M[1, 1]",
+           "  M <- ilogit2(logit_M, M_bounds[1], M_bounds[2], M0)",
+           "  if(conv) {",
+           "    logit_M_sd <- SD$sd[names(SD$value) == \"logit_M\"]",
+           "  } else {",
+           "    logit_M_sd <- rep(0, length(M))",
+           "  }",
+           "  M_upper <- ilogit2(logit_M + 1.96 * logit_M_sd, M_bounds[1], M_bounds[2], M0)",
+           "  M_lower <- ilogit2(logit_M - 1.96 * logit_M_sd, M_bounds[1], M_bounds[2], M0)",
+           "  plot(c(info$Year, max(info$Year) + 1), M, typ = \"o\", xlab = \"Year\", ylab = \"Natural Mortality\", ylim = c(0, 1.1 * max(M_upper)))",
+           "  if(conv) arrows(c(info$Year, max(info$Year) + 1), M_lower, y1 = M_upper, length = 0.025, angle = 90, code = 3, col = \"grey30\")",
+           "  abline(h = 0, col = \"grey\")",
+           "  abline(h = M_bounds, lty = 2)",
            "}",
-           "M_upper <- ilogit2(logit_M + 1.96 * logit_M_sd, M_bounds[1], M_bounds[2], TMB_report$M[1])",
-           "M_lower <- ilogit2(logit_M - 1.96 * logit_M_sd, M_bounds[1], M_bounds[2], TMB_report$M[1])",
-           "plot(info$Year, M, typ = \"o\", ylab = \"Natural Mortality\", ylim = c(0, 1.1 * max(M_upper)))",
-           "if(conv) arrows(info$Year, M_lower, info$Year, M_upper, length = 0.025, angle = 90, code = 3, col = \"grey30\")",
-           "abline(h = 0, col = \"grey\")",
-           "abline(h = M_bounds, lty = 2)",
            "```\n")
   return(out)
 }
 
+
+rmd_M_DD <- function() {
+  out <- c("```{r, fig.cap = \"Density-dependent M as a function of depletion (B/B0). Dotted horizontal lines indicate bounds specified in model.\"}",
+           "DDM <- info$data$tv_M == \"DD\"",
+           "if(DDM) {",
+           "  M <- TMB_report$M[, 1]",
+           "  M_bounds <- obj$env$data$M_bounds",
+           "  plot(c(info$Year, max(info$Year) + 1), M, typ = \"o\", xlab = \"Year\", ylab = \"Natural Mortality\", ylim = c(0, 1.1 * max(M)))",
+           "  abline(h = 0, col = \"grey\")",
+           "  abline(h = M_bounds, lty = 2)",
+           "}",
+           "```\n")
+  return(out)
+}
+
+
 rmd_B_BMSY_terminal <- function() {
   fig.cap <- paste0("Estimate of B/BMSY in terminal year, distribution based on normal approximation of estimated covariance matrix.")
   c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
@@ -237,24 +294,21 @@ rmd_B_B0_terminal <- function() {
 }
 
 
-rmd_sel <- function(age, sel, fig.cap) {
-  age <- vector2char(age)
-  sel <- vector2char(sel)
+rmd_sel <- function(age = "1:info$data$n_age - 1", sel = "Selectivity[nrow(Selectivity), ]", fig.cap) {
   c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
     paste0("plot_ogive(", age, ", ", sel, ")"),
     "```\n")
 }
 
-rmd_sel_persp <- function(age, sel = "Selectivity", fig.cap = "Perspective plot of selectivity.") {
-  age <- vector2char(age)
+rmd_sel_persp <- function(age = "1:info$data$n_age - 1", sel = "Selectivity", 
+                          fig.cap = "Perspective plot of selectivity.") {
   c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
     paste0("persp(info$Year, ", age, ", ", sel, ", expand = 0.35, ticktype = \"detailed\", phi = 25,"),
     paste0("      theta = 45, xlab = \"Year\", ylab = \"Age\", zlab = \"Selectivity\")"),
     "```\n")
 }
 
-rmd_sel_annual <- function(age, sel = "Selectivity", fig.cap = "Annual selectivity.") {
-  age <- vector2char(age)
+rmd_sel_annual <- function(age = "1:info$data$n_age - 1", sel = "Selectivity", fig.cap = "Annual selectivity.") {
   c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
     paste0("plot_composition(info$Year, Selectivity, plot_type = \"annual\", ages = ", age, ", annual_yscale = \"raw\", annual_ylab = \"Selectivity\")"),
     "```\n")
@@ -309,6 +363,19 @@ rmd_assess_fit_series <- function(par = "Index", fig.cap = "index", label = par,
 
 }
 
+rmd_assess_fit_MW <- function() {
+  c("```{r, fig.cap=\"Observed (black) and predicted (red) mean weight.\"}",
+    "plot_timeseries(info$Year, info$data$MW_hist, TMB_report$MWpred, label = \"Mean weight\")",
+    "```\n",
+    "```{r, fig.cap=\"Mean weight residuals in log-space.\"}",
+    "plot_residuals(info$Year, log(info$data$MW_hist/TMB_report$MWpred),",
+    "               label = \"Mean weight log-residuals\")",
+    "```\n",
+    "```{r, fig.cap=\"QQ-plot of log-residuals of mean weight\"}",
+    "qqnorm(log(info$data$MW_hist/TMB_report$MWpred), main = \"\")",
+    "qqline(log(info$data$MW_hist/TMB_report$MWpred))",
+    "```\n")
+}
 
 rmd_assess_timeseries <- function(par, fig.cap, label, header = NULL, conv_check = FALSE, one_line = FALSE) {
   if(conv_check) {
@@ -328,7 +395,7 @@ rmd_assess_timeseries <- function(par, fig.cap, label, header = NULL, conv_check
 rmd_residual <- function(par, se = "NULL", fig.cap, label, conv_check = FALSE, blue = FALSE) {
   if(conv_check) conv <- "if(conv) " else conv <- ""
   if(blue) {
-    blue_arg <- ", res_ind_blue = as.numeric(names(Dev)) < info$Year[1]"
+    blue_arg <- paste0(", res_ind_blue = as.numeric(names(", par,")) < info$Year[1]")
     fig.cap <- paste(fig.cap, "Deviations prior to the first year of the model are in blue.")
   } else {
     blue_arg <- ""
@@ -360,6 +427,23 @@ rmd_fit_age_comps <- function(type = c("bubble", "annual"), ages = "0:(info$data
     "```\n")
 }
 
+rmd_fit_length_comps <- function(type = c("bubble", "annual"), CAL_bins = "info$LH$CAL_mids")  {
+  type <- match.arg(type)
+  if(type == "bubble") {
+    arg <- paste("\"bubble_residuals\", bubble_adj = 20, CAL_bins =", CAL_bins)
+    fig.cap = "Pearson residual bubble plot of length compositions (grey bubbles are negative, white are positive)."
+  } else {
+    arg <- paste("\"annual\", CAL_bins =", CAL_bins)
+    fig.cap <- "Annual observed (black) and predicted (red) length compositions."
+  }
+  c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
+    "ind_valid <- obj$env$data$CAL_n > 0",
+    "CALobs <- obj$env$data$CAL_hist * obj$env$data$CAL_n", 
+    "plot_composition(info$Year[ind_valid], CALobs[ind_valid, ], TMB_report$CALpred[ind_valid, ], N = obj$env$data$CAL_n, ",
+    paste0("                 plot_type = ", arg, ")"),
+    "```\n")
+}
+
 rmd_bubble <- function(year, par, CAL_bins = "NULL", ages = "NULL", fig.cap, bubble_adj = "5") {
   c(paste0("```{r, fig.cap=\"", fig.cap, "\"}"),
     paste0("plot_composition(", year, ", ", par, ", CAL_bins = ", CAL_bins, ", ages = ", ages, ", plot_type = \"bubble_data\", bubble_adj = ", bubble_adj, ")"),
@@ -375,24 +459,24 @@ rmd_F_FMSY <- function(conv_check = TRUE) {
   rmd_assess_timeseries("F_FMSY", "F/FMSY", "expression(F/F[MSY])", conv_check = conv_check, one_line = TRUE)
 }
 
-rmd_U <- function(header = NULL, fig.cap = "harvest rate") {
-  rmd_assess_timeseries("U", fig.cap, "\"Harvest rate (U)\"", header = header)
+rmd_U <- function(header = NULL, fig.cap = "exploitation rate") {
+  rmd_assess_timeseries("U", fig.cap, "\"Exploitation rate (U)\"", header = header)
 }
 
 rmd_U_UMSY <- function(conv_check = TRUE, fig.cap = "U/UMSY") {
   rmd_assess_timeseries("U_UMSY", fig.cap, "expression(U/U[MSY])", conv_check = conv_check, one_line = TRUE)
 }
 
-rmd_SSB <- function() rmd_assess_timeseries("SSB", "spawning biomass", "\"Spawning biomass\"")
+rmd_SSB <- function(var = "SSB") rmd_assess_timeseries(var, "spawning biomass", "\"Spawning biomass\"")
 
-rmd_dynamic_SSB0 <- function(var = "dynamic_SSB0") rmd_assess_timeseries(var, "dynamic SSB0", "\"Dynamic SSB0\"")
+rmd_dynamic_SSB0 <- function(var = "dynamic_SSB0") rmd_assess_timeseries(var, "dynamic SSB0", "expression(\"Dynamic\"~SSB[0])")
 
 rmd_SSB_SSBMSY <- function(conv_check = TRUE) {
   rmd_assess_timeseries("SSB_SSBMSY", "SSB/SSBMSY", "expression(SSB/SSB[MSY])", conv_check = conv_check, one_line = TRUE)
 }
 
-rmd_SSB_SSB0 <- function(conv_check = TRUE) {
-  rmd_assess_timeseries("SSB_SSB0", "spawning depletion", "expression(SSB/SSB[0])", conv_check = conv_check)
+rmd_SSB_SSB0 <- function(conv_check = TRUE, var = "SSB_SSB0") {
+  rmd_assess_timeseries(var, "spawning depletion", "expression(SSB/SSB[0])", conv_check = conv_check)
 }
 
 rmd_B <- function() rmd_assess_timeseries("B", "biomass", "\"Biomass\"")
@@ -405,9 +489,9 @@ rmd_B_B0 <- function(conv_check = TRUE) {
   rmd_assess_timeseries("B_B0", "depletion", "expression(B/B[0])", conv_check = conv_check)
 }
 
-rmd_R <- function() rmd_assess_timeseries("R", "recruitment", "\"Recruitment (R)\"")
+rmd_R <- function(var = "R") rmd_assess_timeseries(var, "recruitment", "\"Recruitment (R)\"")
 
-rmd_N <- function() rmd_assess_timeseries("N", "abundance", "\"Abundance (N)\"")
+rmd_N <- function(var = "N") rmd_assess_timeseries(var, "abundance", "\"Abundance (N)\"")
 
 rmd_N_at_age <- function(ages = "0:(info$data$n_age-1)") {
   rmd_bubble("c(info$Year, max(info$Year)+1)", "N_at_age", ages = ages, fig.cap = "Abundance-at-age bubble plot.")
@@ -423,6 +507,17 @@ rmd_C_mean_age <- function(ages = "0:(info$data$n_age-1)") {
     "```\n")
 }
 
+rmd_C_at_length <- function() {
+  rmd_bubble("info$Year", "TMB_report$CALpred", CAL_bins = "info$LH$CAL_mids", fig.cap = "Predicted catch-at-length bubble plot.")
+}
+
+rmd_C_mean_length <- function() {
+  c("```{r, fig.cap=\"Observed (black) and predicted (red) mean length of the composition data.\"}",
+    "plot_composition(info$Year, obj$env$data$CAL_hist * obj$env$data$CAL_n, TMB_report$CALpred,",
+    "                 CAL_bins = info$LH$CAL_mids, plot_type = \"mean\")",
+    "```\n")
+}
+
 rmd_Kobe <- function(Bvar = "B_BMSY", Fvar = "F_FMSY", xlab = "expression(B/B[MSY])", ylab = "expression(F/F[MSY])",
                      conv_check = TRUE) {
   if(conv_check) conv <- "if(conv) " else conv <- ""
@@ -433,17 +528,16 @@ rmd_Kobe <- function(Bvar = "B_BMSY", Fvar = "F_FMSY", xlab = "expression(B/B[MS
 
 
 #### Productivity
-rmd_SR <- function(Bvec, expectedR, Rpoints, fig.cap = "Stock-recruit relationship.", trajectory = FALSE, ylab = "Recruitment",
-                   conv_check = FALSE, unfished = TRUE, header = NULL) {
-  Bvec <- vector2char(Bvec)
-  expectedR <- vector2char(expectedR)
-  Rpoints <- vector2char(Rpoints)
-  
+rmd_SR <- function(fig.cap = "Stock-recruit relationship.", trajectory = FALSE, ylab = "Recruitment",
+                   conv_check = FALSE, unfished = TRUE, header = NULL, SR_calc = "") {
   if(unfished) refpt <- "R0 = R0, S0 = SSB0, " else refpt <- ""
-  if(conv_check) conv <- "if(conv) " else conv <- ""
+  if(conv_check) conv <- "if(conv) {" else conv <- ""
   ans <- c(paste0("```{r fig.cap=\"", fig.cap, "\"}"),
-           paste0(conv, "plot_SR(", Bvec, ", ", expectedR, ", rec_dev = ", Rpoints, ","),
+           conv,
+           SR_calc,
+           "plot_SR(SSB_SR, R_SR, rec_dev = Rest,",
            paste0(refpt, "ylab = \"", ylab, "\", trajectory = ", as.character(trajectory), ")"),
+           ifelse(conv_check, "}", ""),
            "```\n")
   if(!is.null(header)) ans <- c(header, ans)
   return(ans)
@@ -452,11 +546,11 @@ rmd_SR <- function(Bvec, expectedR, Rpoints, fig.cap = "Stock-recruit relationsh
 rmd_yield_F <- function(model, conv_check = TRUE, header = NULL) {
   if(conv_check) conv <- "if(conv) " else conv <- ""
   if(model == "VPA") {
-    extra_code <- "info$data$SR_type <- info$SR; info$data$mat <- info$LH$mat; TMB_report$vul <- TMB_report$vul_p" 
+    extra_code <- "info$data$SR_type <- info$SR; info$data$mat <- info$LH$mat; TMB_report$vul <- TMB_report$vul_p; TMB_report$M <- matrix(info$data$M, nrow = 1)" 
   } else {
     extra_code <- ""
   }
-
+  
   ans <- c("```{r, fig.cap=\"Yield plot relative to fishing mortality.\"}",
            extra_code,
            paste0(conv, "plot_yield_", model, "(info$data, TMB_report, FMSY, MSY, xaxis = \"F\")"),
@@ -468,7 +562,7 @@ rmd_yield_F <- function(model, conv_check = TRUE, header = NULL) {
 rmd_yield_U <- function(model, conv_check = TRUE, header = NULL) {
   if(conv_check) conv <- "if(conv) " else conv <- ""
 
-  ans <- c("```{r, fig.cap=\"Yield plot relative to harvest rate.\"}",
+  ans <- c("```{r, fig.cap=\"Yield plot relative to exploitation rate.\"}",
            paste0(conv, "plot_yield_", model, "(info$data, TMB_report, UMSY, MSY, xaxis = \"U\")"),
            "```\n")
   if(!is.null(header)) ans <- c(header, ans)
@@ -484,11 +578,12 @@ rmd_yield_depletion <- function(model, conv_check = TRUE) {
     "```\n")
 }
 
-rmd_sp <- function(conv_check = TRUE, depletion = TRUE) {
+rmd_sp <- function(conv_check = TRUE, depletion = TRUE, yield_fn = TRUE) {
   if(conv_check) conv <- "if(conv) " else conv <- ""
   if(depletion) B0 <- "B0" else B0 <- "NULL"
   c("```{r, fig.cap=\"Comparison of historical surplus production and estimated yield curve.\"}",
-    paste0(conv, "plot_surplus_production(B, B0 = ", B0, ", Catch, yield_fn = yield_fn)"),
+    paste0(conv, "plot_surplus_production(B, B0 = ", B0, ", Catch, yield_fn = ", 
+           ifelse(yield_fn, "yield_fn", "NULL"), ")"),
     "```\n")
 }
 
@@ -497,7 +592,7 @@ rmd_SPR <- function(conv_check = TRUE) {
   c("```{r, fig.cap=\"Spawning potential ratio.\"}",
     paste0(conv, " {"),
     "  if(!is.null(forecast$per_recruit$U)) {",
-    "    plot(forecast$per_recruit$U, forecast$per_recruit$SPR, ylim = c(0, 1), typ = \"l\", xlab = \"Harvest rate (U)\", ylab = \"Spawning potential ratio\")",
+    "    plot(forecast$per_recruit$U, forecast$per_recruit$SPR, ylim = c(0, 1), typ = \"l\", xlab = \"Exploitation rate (U)\", ylab = \"Spawning potential ratio\")",
     "  } else {",
     "    plot(forecast$per_recruit$FM, forecast$per_recruit$SPR, ylim = c(0, 1), typ = \"l\", xlab = \"Fishing mortality\", ylab = \"Spawning potential ratio\")",
     "  }",
@@ -511,7 +606,7 @@ rmd_YPR <- function(conv_check = TRUE) {
   c("```{r, fig.cap=\"Yield per recruit.\"}",
     paste0(conv, " {"),
     "  if(!is.null(forecast$per_recruit$U)) {",
-    "    plot(forecast$per_recruit$U, forecast$per_recruit$YPR, typ = \"l\", xlab = \"Harvest rate (U)\", ylab = \"Yield per recruit\")",
+    "    plot(forecast$per_recruit$U, forecast$per_recruit$YPR, typ = \"l\", xlab = \"Exploitation rate (U)\", ylab = \"Yield per recruit\")",
     "    U01 <- get_F01(forecast$per_recruit$U, forecast$per_recruit$YPR)",
     "    Umax <- get_Fmax(forecast$per_recruit$U, forecast$per_recruit$YPR)",
     "    abline(h = 0, col = \"grey\")",
